Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/x68k/x68k Fix a message for NMI.



details:   https://anonhg.NetBSD.org/src/rev/d735a732a4d1
branches:  trunk
changeset: 951989:d735a732a4d1
user:      tsutsui <tsutsui%NetBSD.org@localhost>
date:      Thu Feb 11 02:37:11 2021 +0000

description:
Fix a message for NMI.

Maybe the "keyboard NMI" message was derived from hp300 but
on X68030 NMI is triggered by the NMI button, and there is no
parity check.

diffstat:

 sys/arch/x68k/x68k/machdep.c |  8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diffs (36 lines):

diff -r 5c3f2aa68fde -r d735a732a4d1 sys/arch/x68k/x68k/machdep.c
--- a/sys/arch/x68k/x68k/machdep.c      Thu Feb 11 00:15:55 2021 +0000
+++ b/sys/arch/x68k/x68k/machdep.c      Thu Feb 11 02:37:11 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.204 2021/02/07 15:51:11 tsutsui Exp $    */
+/*     $NetBSD: machdep.c,v 1.205 2021/02/11 02:37:11 tsutsui Exp $    */
 
 /*
  * Copyright (c) 1988 University of Utah.
@@ -39,7 +39,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.204 2021/02/07 15:51:11 tsutsui Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.205 2021/02/11 02:37:11 tsutsui Exp $");
 
 #include "opt_ddb.h"
 #include "opt_kgdb.h"
@@ -957,7 +957,7 @@
 #endif
 
 /*
  * Level 7 interrupts can be caused by the keyboard or parity errors.
  */
 void
 nmihand(struct frame frame)
@@ -975,7 +975,7 @@
                 */
                if (innmihand == 0) {
                        innmihand = 1;
-                       printf("Got a keyboard NMI\n");
+                       printf("NMI button pressed\n");
                        innmihand = 0;
                }
 #ifdef DDB
@@ -957,7 +957,7 @@
 
 /*
- * Level 7 interrupts can be caused by the keyboard or parity errors.
+ * Level 7 interrupts can be caused by the NMI button.
  */
 void



Home | Main Index | Thread Index | Old Index